# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal


class BibliographyDataField(object):
    """
    Const

    These values define parts of bibliographic data.
    
    They are used to create a bibliography in a text document.
    
    Depending on the type of the data some of the fields will usually be left empty.

    See Also:
        `API BibliographyDataField <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html>`_
    """
    IDENTIFIER: Literal[0]
    """
    This field contains a unique identifier for the bibliographic data.
    """
    BIBILIOGRAPHIC_TYPE: Literal[1]
    """
    This field contains the type of the bibliographic reference.
    
    It is of the type BibliographyDataType.
    """
    ADDRESS: Literal[2]
    """
    This field contains the address of the publisher.
    """
    ANNOTE: Literal[3]
    """
    This field contains an annotation.
    """
    AUTHOR: Literal[4]
    """
    This field contains the name(s) of the author(s)
    """
    BOOKTITLE: Literal[5]
    """
    This field contains the title of the book.
    """
    CHAPTER: Literal[6]
    """
    This field contains the name or number of the chapter.
    """
    EDITION: Literal[7]
    """
    This field contains the number or name of the edition.
    """
    EDITOR: Literal[8]
    """
    This field contains the name(s) of the editor(s)
    """
    HOWPUBLISHED: Literal[9]
    """
    This field contains a description of the type of the publishing.
    """
    INSTITUTION: Literal[10]
    """
    This field contains the name of the institution where the publishing was created.
    """
    JOURNAL: Literal[11]
    """
    This field contains the name of the journal.
    """
    MONTH: Literal[12]
    """
    This field contains number or name of the month of the publishing.
    """
    NOTE: Literal[13]
    """
    This field contains a note.
    """
    NUMBER: Literal[14]
    """
    This field contains the number of the publishing.
    """
    ORGANIZATIONS: Literal[15]
    """
    This field contains the name of the organizations where the publishing was created.
    """
    PAGES: Literal[16]
    """
    This field contains the number(s) of the page(s) of the reference into a publishing.
    """
    PUBLISHER: Literal[17]
    """
    This field contains the name of the publisher.
    """
    SCHOOL: Literal[18]
    """
    This field contains the name of the university or school where the publishing was created.
    """
    SERIES: Literal[19]
    """
    This field contains the series of the publishing.
    """
    TITLE: Literal[20]
    """
    This field contains the title of the publishing.
    """
    REPORT_TYPE: Literal[21]
    """
    This field contains a description of the type of the report.
    """
    VOLUME: Literal[22]
    """
    This field contains the volume of the publishing.
    """
    YEAR: Literal[23]
    """
    This field contains the year when the publishing was created.
    """
    URL: Literal[24]
    """
    This field contains URL of the publishing.
    """
    CUSTOM1: Literal[25]
    """
    This field contains user defined data.
    """
    CUSTOM2: Literal[26]
    """
    This field contains user defined data.
    """
    CUSTOM3: Literal[27]
    """
    This field contains user defined data.
    """
    CUSTOM4: Literal[28]
    """
    This field contains user defined data.
    """
    CUSTOM5: Literal[29]
    """
    This field contains user defined data.
    """
    ISBN: Literal[30]
    """
    This field contains the ISBN data of the publishing.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
"""
Const

These values are used to specify the kind of underlining.

They may be expanded in future versions.

See Also:
    `API FontUnderline <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontUnderline.html>`_
"""
NONE: Literal[0]
"""
specifies no underlining.
"""
SINGLE: Literal[1]
"""
specifies underlining with a single line.
"""
DOUBLE: Literal[2]
"""
specifies underlining with a double line.
"""
DOTTED: Literal[3]
"""
specifies underlining with a dotted line.
"""
DONTKNOW: Literal[4]
"""
The kind of underlining is not known.
"""
DASH: Literal[5]
"""
specifies underlining with a dashed line.
"""
LONGDASH: Literal[6]
"""
specifies underlining with long dashes.
"""
DASHDOT: Literal[7]
"""
specifies underlining with a dash and dot sequence.
"""
DASHDOTDOT: Literal[8]
"""
specifies underlining with a dash, dot, dot sequence.
"""
SMALLWAVE: Literal[9]
"""
specifies underlining with a small wave.
"""
WAVE: Literal[10]
"""
specifies underlining with a wave.
"""
DOUBLEWAVE: Literal[11]
"""
specifies underlining with a double wave.
"""
BOLD: Literal[12]
"""
specifies underlining with a bold line.
"""
BOLDDOTTED: Literal[13]
"""
specifies underlining with bold dots.
"""
BOLDDASH: Literal[14]
"""
specifies underlining with bold dashes.
"""
BOLDLONGDASH: Literal[15]
"""
specifies underlining with long bold dashes.
"""
BOLDDASHDOT: Literal[16]
"""
specifies underlining with a dash and dot sequence in bold.
"""
BOLDDASHDOTDOT: Literal[17]
"""
specifies underlining with a dash, dot, dot sequence in bold.
"""
BOLDWAVE: Literal[18]
"""
specifies underlining with a bold wave.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.report
from typing_extensions import Literal


class Calculation(object):
    """
    Const

    Specifies how to calculate a value.

    See Also:
        `API Calculation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1report_1_1Calculation.html>`_
    """
    NONE: Literal[0]
    """
    returns the average of a field.
    """
    AVERAGE: Literal[1]
    """
    returns the average of a field.
    """
    CORRELATION: Literal[2]
    """
    returns the correlation of two fields.
    """
    COUNT: Literal[3]
    """
    counts the number of values, from the field.
    """
    COVARIANCE: Literal[4]
    """
    returns the measure of the linear relation between paired variables.
    """
    DISTINCTCOUNT: Literal[5]
    """
    returns the number of none repeating values, from the field.
    """
    MAXIMUM: Literal[6]
    """
    returns the largest value from the field.
    """
    MEDIAN: Literal[7]
    """
    returns the middle value in a sequence of numeric values.
    """
    MINIMUM: Literal[8]
    """
    returns the smallest value from the field.
    """
    MODE: Literal[9]
    """
    returns the most frequently returning value from the field.
    """
    NTHLARGEST: Literal[10]
    """
    returns the Nth largest value from the field.
    """
    NTHMOSTFREQUENT: Literal[11]
    """
    returns the Nth most commonly occurring value from the field.
    """
    NTHSMALLEST: Literal[12]
    """
    returns the Nth smallest value from the field.
    """
    PERCENTAGE: Literal[13]
    """
    returns as a percentage of the grand total summary.
    """
    PERCENTILE: Literal[14]
    """
    returns the value for a specified percentile in a Number or Currency field.
    """
    POPSTANDARDDEVIATION: Literal[15]
    """
    returns how much each value in the field deviate from the mean or average value for that field.
    """
    POPVARIANCE: Literal[16]
    """
    returns the square of the standard deviation.
    """
    SAMPLESTANDARDDEVIATION: Literal[17]
    """
    returns the sample standard deviation for the field.
    """
    SAMPLEVARIANCE: Literal[18]
    """
    returns the sample variance for the field.
    """
    SUM: Literal[19]
    """
    returns the total of all the values for the field.
    """
    WEIGHTEDAVG: Literal[20]
    """
    returns the weighted average for the field.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..beans.property_value import PropertyValue as PropertyValue_c9610c73


class DispatchStatement(object):
    """
    Struct Class

    represents a dispatch statement from a recorded macro
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API DispatchStatement <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1DispatchStatement.html>`_
    """
    typeName: Literal['com.sun.star.frame.DispatchStatement']

    def __init__(self, aArgs: typing.Optional[typing.Tuple[PropertyValue_c9610c73, ...]] = ..., aCommand: typing.Optional[str] = ..., aTarget: typing.Optional[str] = ..., nFlags: typing.Optional[int] = ..., bIsComment: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            aArgs (typing.Tuple[PropertyValue, ...], optional): aArgs value.
            aCommand (str, optional): aCommand value.
            aTarget (str, optional): aTarget value.
            nFlags (int, optional): nFlags value.
            bIsComment (bool, optional): bIsComment value.
        """


    @property
    def aArgs(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        specifies the dispatch command arguments
        
        That means the Arguments parameter of a corresponding XDispatch.dispatch() request.
        """


    @property
    def aCommand(self) -> str:
        """
        specifies the dispatch command
        
        That means the URL parameter of a corresponding XDispatchProvider.queryDispatch() request.
        """


    @property
    def aTarget(self) -> str:
        """
        specifies the frame target
        
        That means the TargetFrameName parameter of a corresponding XDispatchProvider.queryDispatch() request.
        """


    @property
    def nFlags(self) -> int:
        """
        specifies the optional search flags
        
        That means the SearchFlags parameter of a corresponding XDispatchProvider.queryDispatch() request.
        """


    @property
    def bIsComment(self) -> bool:
        """
        specifies if this statement should be recorded as commented out or not
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal
import typing
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
if typing.TYPE_CHECKING:
    from .x_auto_text_entry import XAutoTextEntry as XAutoTextEntry_c96f0c75
    from .x_text_range import XTextRange as XTextRange_9a910ab7

class XAutoTextGroup(XNameAccess_e2ab0cf6):
    """
    The interface provide methods to insert, rename and delete autotext entries from the current autotext group.

    See Also:
        `API XAutoTextGroup <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextGroup.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XAutoTextGroup']

    def getTitles(self) -> 'typing.Tuple[str, ...]':
        """
        returns the titles of all autotext entries.
        
        The order of the entries corresponds to the output of the function getElementNames().
        """
    def insertNewByName(self, aName: str, aTitle: str, xTextRange: 'XTextRange_9a910ab7') -> 'XAutoTextEntry_c96f0c75':
        """
        creates a new AutoTextEntry entry.

        Raises:
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
    def removeByName(self, aEntryName: str) -> None:
        """
        removes the specified autotext entry.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def renameByName(self, aElementName: str, aNewElementName: str, aNewElementTitle: str) -> None:
        """
        renames an entry in the autotext group.
        
        The position of the autotext entry is not changed.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.io.IOException: ``IOException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.lang
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_content_enumeration_access import XContentEnumerationAccess as XContentEnumerationAccess_c71012d7
from ..container.x_set import XSet as XSet_90c40a4f
from .multi_service_factory import MultiServiceFactory as MultiServiceFactory_b940e5e
from .x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..uno.x_component_context import XComponentContext as XComponentContext_e2e10d4a

class ServiceManager(MultiServiceFactory_b940e5e, XPropertySet_bc180bfa, XContentEnumerationAccess_c71012d7, XSet_90c40a4f, XComponent_98dc0ab5):
    """
    Service Class

    Provides a collection of implementations for services.
    
    This is a singleton you commonly find in your component context under key /singletons/com.sun.star.lang.theServiceManager.
    
    The factories are accessed with a service name. It is possible to access the factories with their implementation names, but you should avoid this.
    
    Service factories added via com.sun.star.container.XSet should support the following interfaces:
    
    Since LibreOffice 3.6, in addition to instances of XServiceInfo et al, the com.sun.star.container.XSet of at least the default C++ service manager implementation now also supports sequences of com.sun.star.beans.NamedValue in insert and remove. The sequence elements must each have a Name of uri and a string Value that is the URI of a service rdb. It is legal for there to be no such uri elements. For insert, there can additionally be an optional element with a Name of component-context and a value that is a non-null reference of type com.sun.star.uno.XComponentContext that shall be used instead of this service manager's default component context when loading the corresponding implementations.

    See Also:
        `API ServiceManager <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1lang_1_1ServiceManager.html>`_
    """
    @property
    def DefaultContext(self) -> 'XComponentContext_e2e10d4a':
        """
        specifies the default component context to be used, if instantiating services via XMultiServiceFactory
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
from typing_extensions import Literal
"""
Const


See Also:
    `API EnhancedCustomShapeSegmentCommand <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html>`_
"""
UNKNOWN: Literal[0]
MOVETO: Literal[1]
LINETO: Literal[2]
CURVETO: Literal[3]
CLOSESUBPATH: Literal[4]
ENDSUBPATH: Literal[5]
NOFILL: Literal[6]
NOSTROKE: Literal[7]
ANGLEELLIPSETO: Literal[8]
ANGLEELLIPSE: Literal[9]
ARCTO: Literal[10]
ARC: Literal[11]
CLOCKWISEARCTO: Literal[12]
CLOCKWISEARC: Literal[13]
ELLIPTICALQUADRANTX: Literal[14]
ELLIPTICALQUADRANTY: Literal[15]
QUADRATICCURVETO: Literal[16]
ARCANGLETO: Literal[17]
DARKEN: Literal[18]
"""
darken fill color
"""
DARKENLESS: Literal[19]
"""
darken fill color less
"""
LIGHTEN: Literal[20]
"""
lighten fill color
"""
LIGHTENLESS: Literal[21]
"""
lighten fill color less
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form
from typing_extensions import Literal
from .x_update_broadcaster import XUpdateBroadcaster as XUpdateBroadcaster_fc910de1

class XBoundComponent(XUpdateBroadcaster_fc910de1):
    """
    specifies a (form) component which is bound to a data source.
    
    The interface provides the possibility of committing its respective data to a data source it is bound to. A commit() will be performed by the environment (usually, a FormController).
    For example, suppose you have a data-bound control that is connected to a database field. Each time the control loses its focus, the model (component) of the control is triggered by the environment to store its value in the database field.
    
    A commit may fail if an XUpdateListener vetoes the it.

    See Also:
        `API XBoundComponent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XBoundComponent.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.XBoundComponent']

    def commit(self) -> bool:
        """
        commits the content of the component into the data source it is bound to.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from .x_spreadsheets import XSpreadsheets as XSpreadsheets_c8f50c64
if typing.TYPE_CHECKING:
    from .x_spreadsheet_document import XSpreadsheetDocument as XSpreadsheetDocument_2a1f0f30

class XSpreadsheets2(XSpreadsheets_c8f50c64):
    """
    extends XSpreadsheets interface to import external sheets.
    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API XSpreadsheets2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XSpreadsheets2']

    def importSheet(self, srcDoc: 'XSpreadsheetDocument_2a1f0f30', srcName: str, nDestPosition: int) -> int:
        """
        copies a sheet from a source document.
        
        **since**
        
            LibreOffice 3.5

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.presentation
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..drawing.x_draw_page import XDrawPage as XDrawPage_b07a0b57
    from .x_slide_show import XSlideShow as XSlideShow_2a80e0e
    from .x_slide_show_listener import XSlideShowListener as XSlideShowListener_81671154

class XSlideShowController(ABC):
    """
    interface to control a running slide show.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XSlideShowController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowController.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.presentation.XSlideShowController']

    def activate(self) -> None:
        """
        activates the user interface of this slide show.
        """
    def addSlideShowListener(self, Listener: 'XSlideShowListener_81671154') -> None:
        """
        adds a listener that receives events while the slide show is running.
        """
    def blankScreen(self, Color: int) -> None:
        """
        pauses the slide show and blanks the screen in the given color.
        
        Change attribute Pause to false to unpause the slide show.
        """
    def deactivate(self) -> None:
        """
        can be called to deactivate the user interface of this slide show.
        
        A deactivated
        """
    def getCurrentSlide(self) -> 'XDrawPage_b07a0b57':
        """
        returns slide that is currently displayed
        """
    def getCurrentSlideIndex(self) -> int:
        """
        returns the index of the current slide.
        """
    def getNextSlideIndex(self) -> int:
        """
        the index for the slide that is displayed next.
        """
    def getSlideByIndex(self, Index: int) -> 'XDrawPage_b07a0b57':
        """
        gives access to the slides that will be shown in this slide show.
        
        Slides are returned in the order they will be displayed in the presentation which can be different than the orders of slides in the document. Not all slides must be present and each slide can be used more than once.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getSlideCount(self) -> int:
        """
        """
    def getSlideShow(self) -> 'XSlideShow_2a80e0e':
        """
        returns the actual XSlideShow instance that runs the slide show.
        
        Normally all navigation should be done using this controller and not the XSlideShow itself.
        """
    def gotoBookmark(self, Bookmark: str) -> None:
        """
        goto the given textual bookmark
        """
    def gotoFirstSlide(self) -> None:
        """
        goto and display first slide
        """
    def gotoLastSlide(self) -> None:
        """
        goto and display last slide.
        
        Remaining effects on the current slide will be skipped.
        """
    def gotoNextEffect(self) -> None:
        """
        start next effects that wait on a generic trigger.
        
        If no generic triggers are waiting the next slide will be displayed.
        """
    def gotoNextSlide(self) -> None:
        """
        goto and display next slide.
        
        Remaining effects on the current slide will be skipped.
        """
    def gotoPreviousEffect(self) -> None:
        """
        undo the last effects that were triggered by a generic trigger.
        
        If there is no previous effect that can be undone then the previous slide will be displayed.
        """
    def gotoPreviousSlide(self) -> None:
        """
        goto and display previous slide.
        
        Remaining effects on the current slide will be skipped.
        """
    def gotoSlide(self, Page: 'XDrawPage_b07a0b57') -> None:
        """
        jumps to the given slide.
        
        The slide can also be a slide that would normally not be shown during the current slide show.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def gotoSlideIndex(self, Index: int) -> None:
        """
        jumps to the slide at the given index.
        """
    def isActive(self) -> bool:
        """
        determines if the slide show is active.
        """
    def isEndless(self) -> bool:
        """
        returns TRUE if the slide show was started to run endlessly.
        """
    def isFullScreen(self) -> bool:
        """
        Returns TRUE if the slide show was started in full-screen mode.
        """
    def isPaused(self) -> bool:
        """
        returns TRUE if the slide show is currently paused.
        """
    def isRunning(self) -> bool:
        """
        returns true if the slide show is still running.
        
        If this returns false, this component is already disposed. You can start a new slide show and get a new instance of XSlideShowController from XPresentation2
        """
    def pause(self) -> None:
        """
        pauses the slide show.
        
        All effects are paused.
        
        The slide show continues on next user input or if resume() is called.
        """
    def removeSlideShowListener(self, Listener: 'XSlideShowListener_81671154') -> None:
        """
        removes a listener.
        """
    def resume(self) -> None:
        """
        resumes a paused slide show.
        """
    def setEraseAllInk(self, EraseAllInk: bool) -> None:
        """
        This method clears ink drawing from the slideshow being played.
        
        **since**
        
            LibreOffice 7.2
        """
    def stopSound(self) -> None:
        """
        stop all currently played sounds
        """
    @property
    def AlwaysOnTop(self) -> bool:
        """
        If this attribute is set to TRUE, the window of the slide show is always on top of all other windows.
        """

    @property
    def MouseVisible(self) -> bool:
        """
        If this attribute is TRUE, the mouse is visible during the slide show.
        """

    @property
    def PenColor(self) -> int:
        """
        This attribute changes the color of the pen.
        """

    @property
    def PenWidth(self) -> float:
        """
        This attribute changes the width of the pen.
        
        **since**
        
            LibreOffice 4.2
        """

    @property
    def UsePen(self) -> bool:
        """
        If this is TRUE, a pen is shown during presentation.
        
        You can draw on the presentation with this pen.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
import typing
from ..container.x_named import XNamed as XNamed_a6520b08
from ..drawing.x_draw_page_supplier import XDrawPageSupplier as XDrawPageSupplier_1a030eab
from .scenario import Scenario as Scenario_8f730a55
from .sheet_cell_range import SheetCellRange as SheetCellRange_d4540c87
from .x_cell_range_movement import XCellRangeMovement as XCellRangeMovement_9730e31
from .x_data_pilot_tables_supplier import XDataPilotTablesSupplier as XDataPilotTablesSupplier_672a10aa
from .x_external_sheet_name import XExternalSheetName as XExternalSheetName_bf60e36
from .x_print_areas import XPrintAreas as XPrintAreas_b0470b72
from .x_scenarios_supplier import XScenariosSupplier as XScenariosSupplier_c9d0e74
from .x_sheet_annotations_supplier import XSheetAnnotationsSupplier as XSheetAnnotationsSupplier_7c1b1154
from .x_sheet_auditing import XSheetAuditing as XSheetAuditing_d47f0ca7
from .x_sheet_linkable import XSheetLinkable as XSheetLinkable_d4620c94
from .x_sheet_outline import XSheetOutline as XSheetOutline_c8760c52
from .x_sheet_page_break import XSheetPageBreak as XSheetPageBreak_e0780cd4
from .x_spreadsheet import XSpreadsheet as XSpreadsheet_bc910bf1
from ..table.x_table_charts_supplier import XTableChartsSupplier as XTableChartsSupplier_26700f09
from ..util.x_protectable import XProtectable as XProtectable_b17f0b93
if typing.TYPE_CHECKING:
    from .x_conditional_formats import XConditionalFormats as XConditionalFormats_1ab20ec9
    from ..util.color import Color as Color_68e908c5

class Spreadsheet(Scenario_8f730a55, SheetCellRange_d4540c87, XNamed_a6520b08, XDrawPageSupplier_1a030eab, XCellRangeMovement_9730e31, XDataPilotTablesSupplier_672a10aa, XExternalSheetName_bf60e36, XPrintAreas_b0470b72, XScenariosSupplier_c9d0e74, XSheetAnnotationsSupplier_7c1b1154, XSheetAuditing_d47f0ca7, XSheetLinkable_d4620c94, XSheetOutline_c8760c52, XSheetPageBreak_e0780cd4, XSpreadsheet_bc910bf1, XTableChartsSupplier_26700f09, XProtectable_b17f0b93):
    """
    Service Class

    represents a complete spreadsheet in a spreadsheet document.
    
    This service extents the service SheetCellRange. A spreadsheet is nothing else than a cell range with extended functionality.
    
    **since**
    
        OOo 3.0

    See Also:
        `API Spreadsheet <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1Spreadsheet.html>`_
    """
    @property
    def AutomaticPrintArea(self) -> bool:
        """
        specifies whether the sheet has an automatic print area.
        
        The automatic print area is used to print a sheet without explicit print areas, also if other sheets have print areas.
        
        If the property is true, and there are print areas on other sheets, the used area of this sheet is also printed.
        
        If the property is false, and there are print areas on other sheets, only these specified print areas are printed.
        
        If there are no print areas on the other sheets it does not matter whether property is true or false.
        
        This property can only be true, if there are no print areas given on this sheet. If the property is set to true the print areas of this sheet will be removed.
        """
    @property
    def ConditionalFormats(self) -> 'XConditionalFormats_1ab20ec9':
        """
        specifies all conditional formats of that sheet
        """
    @property
    def IsVisible(self) -> bool:
        """
        specifies if the sheet is visible.
        """
    @property
    def PageStyle(self) -> str:
        """
        specifies the page style of the sheet.
        """
    @property
    def TabColor(self) -> 'Color_68e908c5':
        """
        specifies the color of the sheet tab, if any.
        """
    @property
    def TableLayout(self) -> int:
        """
        specifies the direction of the columns in the spreadsheet.
        
        Possible values are com.sun.star.text.WritingMode2.LR_TB to order the columns from left to right, and com.sun.star.text.WritingMode2.RL_TB to order the columns from right to left.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.util
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa
    from .color import Color as Color_68e908c5

class XNumberFormatPreviewer(XInterface_8f010a43):
    """
    represents a number formatter which can preview number formats without inserting them.

    See Also:
        `API XNumberFormatPreviewer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormatPreviewer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XNumberFormatPreviewer']

    def convertNumberToPreviewString(self, aFormat: str, fValue: float, nLocale: 'Locale_70d308fa', bAllowEnglish: bool) -> str:
        """
        formats a value using a format string, without inserting a number format into the list.

        Raises:
            com.sun.star.util.MalformedNumberFormatException: ``MalformedNumberFormatException``
        """
    def queryPreviewColorForNumber(self, aFormat: str, fValue: float, nLocale: 'Locale_70d308fa', bAllowEnglish: bool, aDefaultColor: 'Color_68e908c5') -> 'Color_68e908c5':
        """
        returns the color which is to be used for a number.

        Raises:
            com.sun.star.util.MalformedNumberFormatException: ``MalformedNumberFormatException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class LineBreakUserOptions(object):
    """
    Struct Class

    Line break options passed in calls to XBreakIterator.getLineBreak().

    See Also:
        `API LineBreakUserOptions <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1LineBreakUserOptions.html>`_
    """
    typeName: Literal['com.sun.star.i18n.LineBreakUserOptions']

    def __init__(self, forbiddenBeginCharacters: typing.Optional[str] = ..., forbiddenEndCharacters: typing.Optional[str] = ..., applyForbiddenRules: typing.Optional[bool] = ..., allowPunctuationOutsideMargin: typing.Optional[bool] = ..., allowHyphenateEnglish: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            forbiddenBeginCharacters (str, optional): forbiddenBeginCharacters value.
            forbiddenEndCharacters (str, optional): forbiddenEndCharacters value.
            applyForbiddenRules (bool, optional): applyForbiddenRules value.
            allowPunctuationOutsideMargin (bool, optional): allowPunctuationOutsideMargin value.
            allowHyphenateEnglish (bool, optional): allowHyphenateEnglish value.
        """


    @property
    def forbiddenBeginCharacters(self) -> str:
        """
        Characters not allowed at the beginning of a line.
        """


    @property
    def forbiddenEndCharacters(self) -> str:
        """
        Characters not allowed at the end of a line.
        """


    @property
    def applyForbiddenRules(self) -> bool:
        """
        If the forbidden characters rules are to be applied or not.
        """


    @property
    def allowPunctuationOutsideMargin(self) -> bool:
        """
        If punctuation characters are allowed at the end of the line if outside of the margins, resulting in a line not being wrapped if only the punctuation would wrap.
        """


    @property
    def allowHyphenateEnglish(self) -> bool:
        """
        Allow English hyphenation.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..beans.property import Property as Property_8f4e0a76


class ContentInfo(object):
    """
    Struct Class

    A structure for information about contents.

    See Also:
        `API ContentInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1ContentInfo.html>`_
    """
    typeName: Literal['com.sun.star.ucb.ContentInfo']

    def __init__(self, Properties: typing.Optional[typing.Tuple[Property_8f4e0a76, ...]] = ..., Type: typing.Optional[str] = ..., Attributes: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Properties (typing.Tuple[Property, ...], optional): Properties value.
            Type (str, optional): Type value.
            Attributes (int, optional): Attributes value.
        """


    @property
    def Properties(self) -> typing.Tuple[Property_8f4e0a76, ...]:
        """
        This field contains a list with the properties which must be set at a content that was just created using XContentCreator.createNewContent() before it can be committed (by executing the command \"insert\" at the new content).
        
        If one of the properties is missing, the insert command will fail.
        
        In example, a new file system folder content will need a title. The Properties member of the ContentInfo provided for this kind of content must include the property \"Title\".
        
        Important: The required properties must have one of the following basic data types (in order to make it possible to implement client applications with a small set of generic input methods for the values):
        """


    @property
    def Type(self) -> str:
        """
        A type identifier string for a content.
        
        This is an implementation specific string characterizing the kind of a content (e.g. \"application/vnd.sun.star.hierarchy-link\"). The value of this member should match the value returned by XContent.getContentType() of an appropriate content.
        """


    @property
    def Attributes(self) -> int:
        """
        Additional attributes.
        
        These flags contain extra information on the content, like its kind (KIND_FOLDER, KIND_DOCUMENT, KIND_LINK).
        
        It is highly recommended to fill these flags very accurately, as they are very important when transferring contents between different ContentProviders.
        
        The value can be one of the ContentInfoAttribute constants.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XSystemDependentWindowPeer(XInterface_8f010a43):
    """
    provides access to the system dependent implementation of the window.

    See Also:
        `API XSystemDependentWindowPeer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XSystemDependentWindowPeer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XSystemDependentWindowPeer']

    def getWindowHandle(self, ProcessId: 'typing.Tuple[int, ...]', SystemType: int) -> object:
        """
        returns a system-specific window handle.
        
        You must check the machine ID and the process ID.
        WIN32: Returns an HWND if possible, otherwise 0.
        WIN16: Returns an HWND if possible, otherwise 0.
        
        JAVA: Returns a global reference to a java.awt.Component object provided from the JNI-API.
        
        MAC: Returns a ptr to the NSView implementing the window.
        
        XWINDOW: Returns a structure SystemDependentXWindow or void if it is not reachable.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from .sheet_cell_range import SheetCellRange as SheetCellRange_d4540c87
from .x_sheet_cell_cursor import XSheetCellCursor as XSheetCellCursor_ee400d70
from .x_used_area_cursor import XUsedAreaCursor as XUsedAreaCursor_e0c20d01
from ..table.cell_cursor import CellCursor as CellCursor_a3b80b0e

class SheetCellCursor(SheetCellRange_d4540c87, CellCursor_a3b80b0e, XSheetCellCursor_ee400d70, XUsedAreaCursor_e0c20d01):
    """
    Service Class

    represents a cursor in a spreadsheet.
    
    A cursor is a cell range which provides additional methods to move through the table (i.e. to find specific cell ranges).

    See Also:
        `API SheetCellCursor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellCursor.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class DeviceInfo(object):
    """
    Struct Class

    contains information about a device.

    See Also:
        `API DeviceInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1DeviceInfo.html>`_
    """
    typeName: Literal['com.sun.star.awt.DeviceInfo']

    def __init__(self, Width: typing.Optional[int] = ..., Height: typing.Optional[int] = ..., LeftInset: typing.Optional[int] = ..., TopInset: typing.Optional[int] = ..., RightInset: typing.Optional[int] = ..., BottomInset: typing.Optional[int] = ..., PixelPerMeterX: typing.Optional[float] = ..., PixelPerMeterY: typing.Optional[float] = ..., BitsPerPixel: typing.Optional[int] = ..., Capabilities: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Width (int, optional): Width value.
            Height (int, optional): Height value.
            LeftInset (int, optional): LeftInset value.
            TopInset (int, optional): TopInset value.
            RightInset (int, optional): RightInset value.
            BottomInset (int, optional): BottomInset value.
            PixelPerMeterX (float, optional): PixelPerMeterX value.
            PixelPerMeterY (float, optional): PixelPerMeterY value.
            BitsPerPixel (int, optional): BitsPerPixel value.
            Capabilities (int, optional): Capabilities value.
        """


    @property
    def Width(self) -> int:
        """
        contains the width of the device in pixels.
        """


    @property
    def Height(self) -> int:
        """
        contains the height of the device in pixels.
        """


    @property
    def LeftInset(self) -> int:
        """
        contains the inset from the left.
        """


    @property
    def TopInset(self) -> int:
        """
        contains the inset from the top.
        """


    @property
    def RightInset(self) -> int:
        """
        contains the inset from the right.
        """


    @property
    def BottomInset(self) -> int:
        """
        contains the inset from the bottom.
        """


    @property
    def PixelPerMeterX(self) -> float:
        """
        contains the X-axis resolution of the device in pixel/meter.
        """


    @property
    def PixelPerMeterY(self) -> float:
        """
        contains the Y-axis resolution of the device in pixel/meter.
        """


    @property
    def BitsPerPixel(self) -> int:
        """
        contains the color-depth of the device.
        """


    @property
    def Capabilities(self) -> int:
        """
        specifies special operations which are possible on the device.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .rule_term import RuleTerm as RuleTerm_7a4b0972


class Rule(object):
    """
    Struct Class

    describes a rule that can be applies to a number of objects.
    
    A rule consists of a sequence of RuleTerms describing the objects to which the rule should be applied, the RuleAction which should be used on the matching objects, and a parameter.

    See Also:
        `API Rule <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1Rule.html>`_
    """
    typeName: Literal['com.sun.star.ucb.Rule']

    def __init__(self, Terms: typing.Optional[typing.Tuple[RuleTerm_7a4b0972, ...]] = ..., Parameter: typing.Optional[str] = ..., Action: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Terms (typing.Tuple[RuleTerm, ...], optional): Terms value.
            Parameter (str, optional): Parameter value.
            Action (int, optional): Action value.
        """


    @property
    def Terms(self) -> typing.Tuple[RuleTerm_7a4b0972, ...]:
        """
        the rule terms describing the objects to which the rule should be applied.
        """


    @property
    def Parameter(self) -> str:
        """
        Some RuleActions require a parameter.
        """


    @property
    def Action(self) -> int:
        """
        the action to perform on the matching objects.
        
        The value can be one of the RuleAction constants.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.document.ambigous_filter_request import AmbigousFilterRequest as AmbigousFilterRequest
from .._pyi.document.broken_package_request import BrokenPackageRequest as BrokenPackageRequest
from .._pyi.document.changed_by_others_request import ChangedByOthersRequest as ChangedByOthersRequest
from .._pyi.document.cmis_property import CmisProperty as CmisProperty
from .._pyi.document.cmis_version import CmisVersion as CmisVersion
from .._pyi.document.corrupted_filter_configuration_exception import CorruptedFilterConfigurationException as CorruptedFilterConfigurationException
from .._pyi.document.document_event import DocumentEvent as DocumentEvent
from .._pyi.document.document_properties import DocumentProperties as DocumentProperties
from .._pyi.document.document_revision_list_persistence import DocumentRevisionListPersistence as DocumentRevisionListPersistence
from .._pyi.document.empty_undo_stack_exception import EmptyUndoStackException as EmptyUndoStackException
from .._pyi.document.event_descriptor import EventDescriptor as EventDescriptor
from .._pyi.document.event_object import EventObject as EventObject
from .._pyi.document.events import Events as Events
from .._pyi.document.exotic_file_load_exception import ExoticFileLoadException as ExoticFileLoadException
from .._pyi.document.export_filter import ExportFilter as ExportFilter
from .._pyi.document.extended_type_detection import ExtendedTypeDetection as ExtendedTypeDetection
from .._pyi.document.extended_type_detection_factory import ExtendedTypeDetectionFactory as ExtendedTypeDetectionFactory
from .._pyi.document.filter_adapter import FilterAdapter as FilterAdapter
from .._pyi.document.filter_config_refresh import FilterConfigRefresh as FilterConfigRefresh
from .._pyi.document.filter_factory import FilterFactory as FilterFactory
from .._pyi.document.filter_options_request import FilterOptionsRequest as FilterOptionsRequest
from .._pyi.document.graphic_storage_handler import GraphicStorageHandler as GraphicStorageHandler
from .._pyi.document.header_footer_settings import HeaderFooterSettings as HeaderFooterSettings
from .._pyi.document.import_filter import ImportFilter as ImportFilter
from .._pyi.document.indexed_property_values import IndexedPropertyValues as IndexedPropertyValues
from .._pyi.document.link_target import LinkTarget as LinkTarget
from .._pyi.document.link_targets import LinkTargets as LinkTargets
from .._pyi.document.lock_file_corrupt_request import LockFileCorruptRequest as LockFileCorruptRequest
from .._pyi.document.lock_file_ignore_request import LockFileIgnoreRequest as LockFileIgnoreRequest
from .._pyi.document.locked_document_request import LockedDocumentRequest as LockedDocumentRequest
from .._pyi.document.locked_on_saving_request import LockedOnSavingRequest as LockedOnSavingRequest
from .._pyi.document.media_descriptor import MediaDescriptor as MediaDescriptor
from .._pyi.document.named_property_values import NamedPropertyValues as NamedPropertyValues
from .._pyi.document.no_such_filter_request import NoSuchFilterRequest as NoSuchFilterRequest
from .._pyi.document.ooxml_document_properties_importer import OOXMLDocumentPropertiesImporter as OOXMLDocumentPropertiesImporter
from .._pyi.document.office_document import OfficeDocument as OfficeDocument
from .._pyi.document.ole_embedded_server_registration import OleEmbeddedServerRegistration as OleEmbeddedServerRegistration
from .._pyi.document.own_lock_on_document_request import OwnLockOnDocumentRequest as OwnLockOnDocumentRequest
from .._pyi.document.pdf_dialog import PDFDialog as PDFDialog
from .._pyi.document.read_only_open_request import ReadOnlyOpenRequest as ReadOnlyOpenRequest
from .._pyi.document.reload_editable_request import ReloadEditableRequest as ReloadEditableRequest
from .._pyi.document.settings import Settings as Settings
from .._pyi.document.type_detection import TypeDetection as TypeDetection
from .._pyi.document.undo_context_not_closed_exception import UndoContextNotClosedException as UndoContextNotClosedException
from .._pyi.document.undo_failed_exception import UndoFailedException as UndoFailedException
from .._pyi.document.undo_manager_event import UndoManagerEvent as UndoManagerEvent
from .._pyi.document.x_action_lockable import XActionLockable as XActionLockable
from .._pyi.document.x_binary_stream_resolver import XBinaryStreamResolver as XBinaryStreamResolver
from .._pyi.document.x_cmis_document import XCmisDocument as XCmisDocument
from .._pyi.document.x_code_name_query import XCodeNameQuery as XCodeNameQuery
from .._pyi.document.x_compat_writer_doc_properties import XCompatWriterDocProperties as XCompatWriterDocProperties
from .._pyi.document.x_document_event_broadcaster import XDocumentEventBroadcaster as XDocumentEventBroadcaster
from .._pyi.document.x_document_event_listener import XDocumentEventListener as XDocumentEventListener
from .._pyi.document.x_document_insertable import XDocumentInsertable as XDocumentInsertable
from .._pyi.document.x_document_languages import XDocumentLanguages as XDocumentLanguages
from .._pyi.document.x_document_properties import XDocumentProperties as XDocumentProperties
from .._pyi.document.x_document_properties_supplier import XDocumentPropertiesSupplier as XDocumentPropertiesSupplier
from .._pyi.document.x_document_recovery import XDocumentRecovery as XDocumentRecovery
from .._pyi.document.x_document_revision_list_persistence import XDocumentRevisionListPersistence as XDocumentRevisionListPersistence
from .._pyi.document.x_document_sub_storage_supplier import XDocumentSubStorageSupplier as XDocumentSubStorageSupplier
from .._pyi.document.x_embedded_object_resolver import XEmbeddedObjectResolver as XEmbeddedObjectResolver
from .._pyi.document.x_embedded_object_supplier import XEmbeddedObjectSupplier as XEmbeddedObjectSupplier
from .._pyi.document.x_embedded_object_supplier2 import XEmbeddedObjectSupplier2 as XEmbeddedObjectSupplier2
from .._pyi.document.x_embedded_scripts import XEmbeddedScripts as XEmbeddedScripts
from .._pyi.document.x_event_broadcaster import XEventBroadcaster as XEventBroadcaster
from .._pyi.document.x_event_listener import XEventListener as XEventListener
from .._pyi.document.x_events_supplier import XEventsSupplier as XEventsSupplier
from .._pyi.document.x_exporter import XExporter as XExporter
from .._pyi.document.x_extended_filter_detection import XExtendedFilterDetection as XExtendedFilterDetection
from .._pyi.document.x_filter import XFilter as XFilter
from .._pyi.document.x_filter_adapter import XFilterAdapter as XFilterAdapter
from .._pyi.document.x_graphic_object_resolver import XGraphicObjectResolver as XGraphicObjectResolver
from .._pyi.document.x_graphic_storage_handler import XGraphicStorageHandler as XGraphicStorageHandler
from .._pyi.document.x_importer import XImporter as XImporter
from .._pyi.document.x_interaction_filter_options import XInteractionFilterOptions as XInteractionFilterOptions
from .._pyi.document.x_interaction_filter_select import XInteractionFilterSelect as XInteractionFilterSelect
from .._pyi.document.x_link_target_supplier import XLinkTargetSupplier as XLinkTargetSupplier
from .._pyi.document.xml_basic_exporter import XMLBasicExporter as XMLBasicExporter
from .._pyi.document.xml_oasis_basic_exporter import XMLOasisBasicExporter as XMLOasisBasicExporter
from .._pyi.document.x_mime_type_info import XMimeTypeInfo as XMimeTypeInfo
from .._pyi.document.xooxml_document_properties_importer import XOOXMLDocumentPropertiesImporter as XOOXMLDocumentPropertiesImporter
from .._pyi.document.x_redlines_supplier import XRedlinesSupplier as XRedlinesSupplier
from .._pyi.document.x_script_invocation_context import XScriptInvocationContext as XScriptInvocationContext
from .._pyi.document.x_shape_event_broadcaster import XShapeEventBroadcaster as XShapeEventBroadcaster
from .._pyi.document.x_shape_event_listener import XShapeEventListener as XShapeEventListener
from .._pyi.document.x_storage_based_document import XStorageBasedDocument as XStorageBasedDocument
from .._pyi.document.x_storage_change_listener import XStorageChangeListener as XStorageChangeListener
from .._pyi.document.x_type_detection import XTypeDetection as XTypeDetection
from .._pyi.document.x_undo_action import XUndoAction as XUndoAction
from .._pyi.document.x_undo_manager import XUndoManager as XUndoManager
from .._pyi.document.x_undo_manager_listener import XUndoManagerListener as XUndoManagerListener
from .._pyi.document.x_undo_manager_supplier import XUndoManagerSupplier as XUndoManagerSupplier
from .._pyi.document.x_vba_method_parameter import XVbaMethodParameter as XVbaMethodParameter
from .._pyi.document.x_view_data_supplier import XViewDataSupplier as XViewDataSupplier
from .._pyi.document.xxml_basic_exporter import XXMLBasicExporter as XXMLBasicExporter



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.frame
from typing_extensions import Literal
from .x_component_loader import XComponentLoader as XComponentLoader_eede0d75
from .x_desktop import XDesktop as XDesktop_8e740a45
from .x_dispatch_provider import XDispatchProvider as XDispatchProvider_fc690de6
from .x_dispatch_provider_interception import XDispatchProviderInterception as XDispatchProviderInterception_c2a512da
from .x_frames_supplier import XFramesSupplier as XFramesSupplier_e12a0d1d

class XDesktop2(XComponentLoader_eede0d75, XDesktop_8e740a45, XDispatchProvider_fc690de6, XDispatchProviderInterception_c2a512da, XFramesSupplier_e12a0d1d):
    """
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API XDesktop2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDesktop2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XDesktop2']





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal
from .x_text_content import XTextContent as XTextContent_b16e0ba5

class XDocumentIndex(XTextContent_b16e0ba5):
    """
    This is the main interface for a document index.
    
    Use com.sun.star.util.XRefreshable and com.sun.star.lang.XServiceInfo instead, if available.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XDocumentIndex <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XDocumentIndex.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.text.XDocumentIndex']

    def getServiceName(self) -> str:
        """
        returns the service name that was used to create this document index type.
        """
    def update(self) -> None:
        """
        initiates an update to the document index.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
"""
Const

These values are used to specify the general kind of font.

They may be expanded in future versions.

See Also:
    `API FontFamily <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontFamily.html>`_
"""
DONTKNOW: Literal[0]
"""
specifies an unknown font family.
"""
DECORATIVE: Literal[1]
"""
specifies the family of decorative fonts.
"""
MODERN: Literal[2]
"""
specifies the family of modern fonts.
"""
ROMAN: Literal[3]
"""
specifies the family roman fonts (with serifs).
"""
SCRIPT: Literal[4]
"""
specifies the family of script fonts.
"""
SWISS: Literal[5]
"""
specifies the family roman fonts (without serifs).
"""
SYSTEM: Literal[6]
"""
specifies the family system fonts.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.dom.events
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum

ENUM EventType

See Also:
    `API EventType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events.html#a2628ea8d12e8b2563c32f05dc7fff6fa>`_
"""

DOMActivate: 'uno.Enum'
"""
"""
DOMAttrModified: 'uno.Enum'
"""
"""
DOMCharacterDataModified: 'uno.Enum'
"""
"""
DOMFocusIn: 'uno.Enum'
"""
"""
DOMFocusOut: 'uno.Enum'
"""
"""
DOMNodeInserted: 'uno.Enum'
"""
"""
DOMNodeInsertedIntoDocument: 'uno.Enum'
"""
"""
DOMNodeRemoved: 'uno.Enum'
"""
"""
DOMNodeRemovedFromDocument: 'uno.Enum'
"""
"""
DOMSubtreeModified: 'uno.Enum'
"""
"""
click: 'uno.Enum'
"""
"""
mousedown: 'uno.Enum'
"""
"""
mousemove: 'uno.Enum'
"""
"""
mouseout: 'uno.Enum'
"""
"""
mouseover: 'uno.Enum'
"""
"""
mouseup: 'uno.Enum'
"""
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from ..accessibility.x_accessible_component import XAccessibleComponent as XAccessibleComponent_b2f21269
from ..accessibility.x_accessible_context import XAccessibleContext as XAccessibleContext_8eae119b
from ..accessibility.x_accessible_event_broadcaster import XAccessibleEventBroadcaster as XAccessibleEventBroadcaster_3d811522
from ..accessibility.x_accessible_image import XAccessibleImage as XAccessibleImage_6bc11099

class AccessibleTextEmbeddedObject(XAccessibleComponent_b2f21269, XAccessibleContext_8eae119b, XAccessibleEventBroadcaster_3d811522, XAccessibleImage_6bc11099):
    """
    Service Class

    The accessible view of an inactive embedded object.
    
    If an embedded object gets active, the active document gets an accessible object tree of its own. This tree is not a subtree of the object that supports this service but of the document service itself. The tree exist only until the object is deactivated.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleTextEmbeddedObject <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1AccessibleTextEmbeddedObject.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_frame import XFrame as XFrame_7a570956
    from .x_load_event_listener import XLoadEventListener as XLoadEventListener_9140e33

class XFrameLoader(XInterface_8f010a43):
    """
    load components into a frame
    
    It's an asynchronous loading. For synchronous processes use XSynchronousFrameLoader instead of this one. The generic load algorithm of the office supports both ones - but preferred the synchronous interface.

    See Also:
        `API XFrameLoader <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XFrameLoader.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XFrameLoader']

    def cancel(self) -> None:
        """
        cancels the loading process.
        
        After returning from this call, neither the frame nor the load-event-listener specified in XFrameLoader.load() may be called back. Because only the owner of this process who called load method before can cancel this process. And he doesn't need any notification about that. On the other hand - nobody then this owner himself can be registered as an XLoadEventListener here.
        """
    def load(self, Frame: 'XFrame_7a570956', URL: str, Arguments: 'typing.Tuple[PropertyValue_c9610c73, ...]', Listener: 'XLoadEventListener_9140e33') -> None:
        """
        starts the loading of the specified resource into the specified Frame.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
from ..lang.x_component import XComponent as XComponent_98dc0ab5

class XMSAAService(XComponent_98dc0ab5):
    """
    The interface must be implemented for a server that can support MSAA com objects and send win32 accessible events.

    See Also:
        `API XMSAAService <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XMSAAService.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XMSAAService']

    def getAccObjectPtr(self, hWnd: int, lParam: int, wParam: int) -> int:
        """
        Return com object pointer.
        """
    def handleWindowOpened(self, i: int) -> None:
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class ContextInformation(object):
    """
    Struct Class

    provides information about a certain stack frame.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API ContextInformation <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1script_1_1ContextInformation.html>`_
    """
    typeName: Literal['com.sun.star.script.ContextInformation']

    def __init__(self, LocalVariableNames: typing.Optional[typing.Tuple[str, ...]] = ..., Name: typing.Optional[str] = ..., SourceCode: typing.Optional[str] = ..., StartLine: typing.Optional[int] = ..., StartColumn: typing.Optional[int] = ..., EndLine: typing.Optional[int] = ..., EndColumn: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            LocalVariableNames (typing.Tuple[str, ...], optional): LocalVariableNames value.
            Name (str, optional): Name value.
            SourceCode (str, optional): SourceCode value.
            StartLine (int, optional): StartLine value.
            StartColumn (int, optional): StartColumn value.
            EndLine (int, optional): EndLine value.
            EndColumn (int, optional): EndColumn value.
        """


    @property
    def LocalVariableNames(self) -> typing.Tuple[str, ...]:
        """
        Get all names of the local variable in this context.
        """


    @property
    def Name(self) -> str:
        """
        Full qualified name to address the module or function associated with the context.
        
        If the module or function can't be addressed by name, e.g., in case that a runtime generated eval-module is executed, this string is empty
        """


    @property
    def SourceCode(self) -> str:
        """
        Source code of the Module, that is associated with the context.
        
        If the source can be accessed using the ModuleName or if the source is unknown (executing compiled code) this string can be empty.
        """


    @property
    def StartLine(self) -> int:
        """
        contains the first line in the module's source code associated with the context.
        
        If \"name\" addresses a function, all line and column values are nevertheless given relative to the module's source. If source code is not available, this value addresses a binary position in the compiled code.
        """


    @property
    def StartColumn(self) -> int:
        """
        contains the first column in the StartLine associated with the context.
        """


    @property
    def EndLine(self) -> int:
        """
        contains the last line in the module's source code associated with the context.
        """


    @property
    def EndColumn(self) -> int:
        """
        contains the first column in the EndLine that is NOT associated with the context.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .xsql_input import XSQLInput as XSQLInput_8c4109fc
    from .xsql_output import XSQLOutput as XSQLOutput_96fb0a7d

class XSQLData(XInterface_8f010a43):
    """
    is used for the custom mapping of SQL user-defined types.
    
    This interface must be implemented by a service that is registered in a type mapping. It is expected that this interface will normally be implemented by a tool. The methods in this interface are called by the driver and are never called by a programmer directly.

    See Also:
        `API XSQLData <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLData.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbc.XSQLData']

    def getSQLTypeName(self) -> str:
        """
        returns the fully-qualified name of the SQL user-defined type that this object represents.
        
        This method is called by the SDBC driver to get the name of the UDT instance that is being mapped to this instance of SQLData.

        Raises:
            SQLException: ``SQLException``
        """
    def readSQL(self, stream: 'XSQLInput_8c4109fc', typeName: str) -> None:
        """
        populates this object with data read from the database.
        
        The implementation of the method must follow this protocol:
        It must read each of the attributes or elements of the SQL type from the given input stream. This is done by calling a method of the input stream to read each item, in the order that they appear in the SQL definition of the type. The method readSQL then assigns the data to appropriate fields or elements (of this or other objects).
        Specifically, it must call the appropriate XSQLInput.readXXX method(s) to do the following: for a Distinct Type, read its single data element; for a Structured Type, read a value for each attribute of the SQL type.
        
        The SDBC driver initializes the input stream with a type map before calling this method, which is used by the appropriate SQLInput.readXXX method on the stream.

        Raises:
            SQLException: ``SQLException``
        """
    def writeSQL(self, stream: 'XSQLOutput_96fb0a7d') -> None:
        """
        writes this object to the given SQL data stream.
        
        The implementation of the method must follow this protocol:
        It must write each of the attributes of the SQL type to the given output stream. This is done by calling a method of the output stream to write each item, in the order that they appear in the SQL definition of the type. Specifically, it must call the appropriate XSQLOutput.writeXXX method(s) to do the following:
        for a Distinct Type, write its single data element; for a Structured Type, write a value for each attribute of the SQL type.

        Raises:
            SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API IOErrorCode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5>`_
"""

ABORT: 'uno.Enum'
"""
An operation was aborted.
"""
ACCESS_DENIED: 'uno.Enum'
"""
An object cannot be accessed due to insufficient user rights.
"""
ALREADY_EXISTING: 'uno.Enum'
"""
An object already exists.
"""
BAD_CRC: 'uno.Enum'
"""
A bad checksum.
"""
CANT_CREATE: 'uno.Enum'
"""
An object could not be created.
"""
CANT_READ: 'uno.Enum'
"""
Data could not be read from a file.
"""
CANT_SEEK: 'uno.Enum'
"""
A seek operation could not be run.
"""
CANT_TELL: 'uno.Enum'
"""
A tell operation could not be run.
"""
CANT_WRITE: 'uno.Enum'
"""
Data could not be written to a file.
"""
CURRENT_DIRECTORY: 'uno.Enum'
"""
A function is not possible because the path contains the current directory.
"""
DEVICE_NOT_READY: 'uno.Enum'
"""
A device (drive) not ready.
"""
DIFFERENT_DEVICES: 'uno.Enum'
"""
A function is not possible because the devices (drives) are not identical.
"""
GENERAL: 'uno.Enum'
"""
A general input/output error.
"""
INVALID_ACCESS: 'uno.Enum'
"""
An invalid attempt was made to access an object.
"""
INVALID_CHARACTER: 'uno.Enum'
"""
A file name contains invalid characters.
"""
INVALID_DEVICE: 'uno.Enum'
"""
A specified device is invalid.
"""
INVALID_LENGTH: 'uno.Enum'
"""
Invalid data length.
"""
INVALID_PARAMETER: 'uno.Enum'
"""
An operation was started with an invalid parameter.
"""
IS_WILDCARD: 'uno.Enum'
"""
An operation cannot be run on file names containing wildcards.
"""
LOCKING_VIOLATION: 'uno.Enum'
"""
A locking problem.
"""
MISPLACED_CHARACTER: 'uno.Enum'
"""
An invalid file name.
"""
NAME_TOO_LONG: 'uno.Enum'
"""
A file name is too long.
"""
NOT_EXISTING: 'uno.Enum'
"""
A nonexistent object.
"""
NOT_EXISTING_PATH: 'uno.Enum'
"""
The path to a file does not exist.
"""
NOT_SUPPORTED: 'uno.Enum'
"""
An action is not supported.
"""
NO_DIRECTORY: 'uno.Enum'
"""
An object is not a directory.
"""
NO_FILE: 'uno.Enum'
"""
An object is not a file.
"""
OUT_OF_DISK_SPACE: 'uno.Enum'
"""
No more space on a device.
"""
OUT_OF_FILE_HANDLES: 'uno.Enum'
"""
No more file handles available.
"""
OUT_OF_MEMORY: 'uno.Enum'
"""
An operation could not be run due to insufficient memory.
"""
PENDING: 'uno.Enum'
"""
An operation is still pending.
"""
RECURSIVE: 'uno.Enum'
"""
An object cannot be copied into itself.
"""
UNKNOWN: 'uno.Enum'
"""
Unknown.

An unknown I/O error has occurred.
"""
WRITE_PROTECTED: 'uno.Enum'
"""
A function is not possible because the object is write protected.
"""
WRONG_FORMAT: 'uno.Enum'
"""
An incorrect file format.
"""
WRONG_VERSION: 'uno.Enum'
"""
An incorrect file version.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal


class LinguServiceEventFlags(object):
    """
    Const

    to be used in lingu-service events.
    
    These values define the flags which may be logically combined to build the event type of a com.sun.star.linguistic2.LinguServiceEvent
    
    **since**
    
        OOo 3.0.1

    See Also:
        `API LinguServiceEventFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1linguistic2_1_1LinguServiceEventFlags.html>`_
    """
    SPELL_CORRECT_WORDS_AGAIN: Literal[1]
    """
    The spelling of previously correct words should be checked again.
    """
    SPELL_WRONG_WORDS_AGAIN: Literal[2]
    """
    The spelling of previously misspelled words should be checked again.
    """
    HYPHENATE_AGAIN: Literal[4]
    """
    The hyphenation of words may have changed.
    """
    PROOFREAD_AGAIN: Literal[8]
    """
    Request new proofreading of the document.
    
    **since**
    
        OOo 3.0.1
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script
# Libre Office Version: 7.2
from typing_extensions import Literal
from .all_event_object import AllEventObject as AllEventObject_e2c20d0f
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class ScriptEvent(AllEventObject_e2c20d0f):
    """
    Struct Class

    script event that gets delivered whenever a script event takes place.
    
    For that to happen, a \"ScriptEventDescriptor\" must be registered at and attached to an object by an XEventAttacherManager.

    See Also:
        `API ScriptEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1script_1_1ScriptEvent.html>`_
    """
    typeName: Literal['com.sun.star.script.ScriptEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., Arguments: typing.Optional[typing.Tuple[object, ...]] = ..., Helper: typing.Optional[object] = ..., ListenerType: typing.Optional[object] = ..., MethodName: typing.Optional[str] = ..., ScriptType: typing.Optional[str] = ..., ScriptCode: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Arguments (typing.Tuple[object, ...], optional): Arguments value.
            Helper (object, optional): Helper value.
            ListenerType (object, optional): ListenerType value.
            MethodName (str, optional): MethodName value.
            ScriptType (str, optional): ScriptType value.
            ScriptCode (str, optional): ScriptCode value.
        """


    @property
    def ScriptType(self) -> str:
        """
        type of the script language as string; for example, \"Basic\" or \"StarScript\".
        """


    @property
    def ScriptCode(self) -> str:
        """
        script code as string.
        
        The code has to correspond with the language defined by ScriptType.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.style
from typing_extensions import Literal
from ..container.x_named import XNamed as XNamed_a6520b08

class XStyle(XNamed_a6520b08):
    """
    specifies a template for a style (aka style sheet).

    See Also:
        `API XStyle <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1style_1_1XStyle.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.style.XStyle']

    def getParentStyle(self) -> str:
        """
        """
    def isInUse(self) -> bool:
        """
        """
    def isUserDefined(self) -> bool:
        """
        identifies a style as defined by the user.
        """
    def setParentStyle(self, aParentStyle: str) -> None:
        """
        sets the name of the parent style.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.resource
import typing
from .x_string_resource_with_location import XStringResourceWithLocation as XStringResourceWithLocation_dd27135c
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa
    from ..task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class StringResourceWithLocation(XStringResourceWithLocation_dd27135c):
    """
    Service Class

    specifies a service providing access to a resource string table implementing the com.sun.star.resource.XStringResourceWithLocation interface.

    See Also:
        `API StringResourceWithLocation <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1resource_1_1StringResourceWithLocation.html>`_
    """
    def create(self, URL: str, ReadOnly: bool, locale: 'Locale_70d308fa', BaseName: str, Comment: str, Handler: 'XInteractionHandler_bf80e51') -> None:
        """
        is used to initialize the object on its creation.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.2
from typing_extensions import Literal
from .calendar_item import CalendarItem as CalendarItem_a86c0af1
import typing


class CalendarItem2(CalendarItem_a86c0af1):
    """
    Struct Class

    One entry in a calendar, for example, a day of week or a month or an era.
    
    Derived from com.sun.star.i18n.CalendarItem this provides an additional member for narrow names.
    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API CalendarItem2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1CalendarItem2.html>`_
    """
    typeName: Literal['com.sun.star.i18n.CalendarItem2']

    def __init__(self, ID: typing.Optional[str] = ..., AbbrevName: typing.Optional[str] = ..., FullName: typing.Optional[str] = ..., NarrowName: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            ID (str, optional): ID value.
            AbbrevName (str, optional): AbbrevName value.
            FullName (str, optional): FullName value.
            NarrowName (str, optional): NarrowName value.
        """


    @property
    def NarrowName(self) -> str:
        """
        The narrow name, for example, \"S\" for Sunday or \"J\" for January.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.datatransfer
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XSystemTransferable(XInterface_8f010a43):
    """
    Interface to be implemented by objects used to provide system dependent data for a transfer operation.
    
    Those objects usually also implement XTransferable.

    See Also:
        `API XSystemTransferable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1XSystemTransferable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.datatransfer.XSystemTransferable']

    def getData(self, aProcessId: 'typing.Tuple[int, ...]') -> object:
        """
        Called by a data consumer to obtain a system specific data object from the source.
        
        The data object is returned in an any. The contained type may differ on different platforms.
        
        Notes:Under Windows the returned any contains an unsigned long which represents a pointer to an IDataObject interface. The caller of getData has to release the data object (IDataObject.Release) if it is no longer needed. The caller must also make sure that the current thread has been initialized for OLE (use OleInitialize).
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.io
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XConnectable(XInterface_8f010a43):
    """
    makes it possible to connect data sinks and sources.
    
    The predecessor-member is the element in the connection that is nearer to the source of the data. The successor-member is the element that is further away from the source of the data. (Note that this classification does not depend on whether the class implements XInputStream or XOutputStream; it only depends on the direction of data flow.)
    
    This interface allows generic services to navigate between arbitrary elements of a connection.

    See Also:
        `API XConnectable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XConnectable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.io.XConnectable']

    def getPredecessor(self) -> 'XConnectable':
        """
        """
    def getSuccessor(self) -> 'XConnectable':
        """
        """
    def setPredecessor(self, aPredecessor: 'XConnectable') -> None:
        """
        sets the source of the data flow for this object.
        """
    def setSuccessor(self, aSuccessor: 'XConnectable') -> None:
        """
        sets the sink of the data flow for this object.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from .x_sheet_cell_range import XSheetCellRange as XSheetCellRange_e09d0cdf
if typing.TYPE_CHECKING:
    from .x_sheet_cell_cursor import XSheetCellCursor as XSheetCellCursor_ee400d70

class XSpreadsheet(XSheetCellRange_e09d0cdf):
    """
    provides methods to create a cell range cursor.

    See Also:
        `API XSpreadsheet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheet.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XSpreadsheet']

    def createCursor(self) -> 'XSheetCellCursor_ee400d70':
        """
        creates a cell cursor including the whole spreadsheet.
        """
    def createCursorByRange(self, aRange: 'XSheetCellRange_e09d0cdf') -> 'XSheetCellCursor_ee400d70':
        """
        creates a cell cursor to travel in the given range context.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart2
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XTransformation(XInterface_8f010a43):
    """
    allows the transformation of numeric values from one coordinate-system into another.
    
    Values may be transformed using any mapping.

    See Also:
        `API XTransformation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XTransformation.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.XTransformation']

    def getSourceDimension(self) -> int:
        """
        the dimension of the input coordinate sequence that is to be transformed by the transform() method.
        """
    def getTargetDimension(self) -> int:
        """
        the dimension of the output coordinate sequence that is the result of the transform() method.
        """
    def transform(self, aValues: 'typing.Tuple[float, ...]') -> 'typing.Tuple[float, ...]':
        """
        transforms the given input data tuple, given in the source coordinate system, according to the internal transformation rules, into a tuple of transformed coordinates in the destination coordinate system.
        
        Note that both coordinate systems may have different dimensions, e.g., if a transformation does simply a projection into a lower-dimensional space.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart2
import typing
from ..beans.property_set import PropertySet as PropertySet_b0e70ba2
from .x_title import XTitle as XTitle_833f09a6
from ..drawing.fill_properties import FillProperties as FillProperties_f1200da8
from ..drawing.line_properties import LineProperties as LineProperties_f13f0da9
from ..style.paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from .relative_position import RelativePosition as RelativePosition_fae10ddd

class Title(PropertySet_b0e70ba2, FillProperties_f1200da8, LineProperties_f13f0da9, ParagraphProperties_1e240efc, XTitle_833f09a6):
    """
    Service Class


    See Also:
        `API Title <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1Title.html>`_
    """
    @property
    def ReferencePageSize(self) -> 'Size_576707ef':
        """
        contains the size of the page at the time when properties were set (e.g.
        
        the CharHeight).
        
        This way it is possible to resize objects (like text) in the view without modifying the model.
        """
    @property
    def RelativePosition(self) -> 'RelativePosition_fae10ddd':
        """
        The position is a relative position on the page.
        
        If a relative position is given the title is not automatically placed, but instead is placed relative on the page.
        """
    @property
    def StackCharacters(self) -> bool:
        """
        writes the characters of the title on top of each other if set to TRUE.
        """
    @property
    def TextRotation(self) -> float:
        """
        the rotation of the title's text in degrees in the range [0,360).
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XViewSplitable(XInterface_8f010a43):
    """
    enables a SpreadsheetView to split the view.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XViewSplitable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XViewSplitable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XViewSplitable']

    def getIsWindowSplit(self) -> bool:
        """
        returns TRUE if the view is split into individual panes.
        
        Only one of XViewSplitable.getIsWindowSplit() and XViewFreezable.hasFrozenPanes() can be TRUE.
        """
    def getSplitColumn(self) -> int:
        """
        returns the column before which the view is split.
        """
    def getSplitHorizontal(self) -> int:
        """
        returns the horizontal position in pixels where the view is split.
        """
    def getSplitRow(self) -> int:
        """
        returns the row before which the view is split.
        """
    def getSplitVertical(self) -> int:
        """
        returns the vertical position in pixels where the view is split.
        """
    def splitAtPosition(self, nPixelX: int, nPixelY: int) -> None:
        """
        splits the view at the specified position.
        
        To split only horizontally, specify nPixelY as 0. To split only vertically, specify nPixelX as 0.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class ChartSeriesAddress(object):
    """
    Struct Class

    This structure describes a single data row, specified by its name and a sequence of data points.
    
    The cell addresses are in the format of the application that contains this chart.

    See Also:
        `API ChartSeriesAddress <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart_1_1ChartSeriesAddress.html>`_
    """
    typeName: Literal['com.sun.star.chart.ChartSeriesAddress']

    def __init__(self, DomainRangeAddresses: typing.Optional[typing.Tuple[str, ...]] = ..., DataRangeAddress: typing.Optional[str] = ..., LabelAddress: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            DomainRangeAddresses (typing.Tuple[str, ...], optional): DomainRangeAddresses value.
            DataRangeAddress (str, optional): DataRangeAddress value.
            LabelAddress (str, optional): LabelAddress value.
        """


    @property
    def DomainRangeAddresses(self) -> typing.Tuple[str, ...]:
        """
        contains cell addresses for each domain of this series.
        
        For XY (scatter) diagrams at least one series has a domain. Most of the other chart types use an empty sequence here.
        """


    @property
    def DataRangeAddress(self) -> str:
        """
        contains the cell range address of the data for this series.
        """


    @property
    def LabelAddress(self) -> str:
        """
        contains the cell address of label (i.e.
        
        name) of this series.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.util
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_mode_change_approve_listener import XModeChangeApproveListener as XModeChangeApproveListener_7807110c
    from .x_mode_change_listener import XModeChangeListener as XModeChangeListener_9c30e2f

class XModeChangeBroadcaster(XInterface_8f010a43):
    """
    broadcasts changes in an object's internal mode.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XModeChangeBroadcaster <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XModeChangeBroadcaster']

    def addModeChangeApproveListener(self, rxListener: 'XModeChangeApproveListener_7807110c') -> None:
        """
        adds the given listener to the list of components to be notified when the mode is about to change.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
    def addModeChangeListener(self, rxListener: 'XModeChangeListener_9c30e2f') -> None:
        """
        adds the given listener to the list of components to be notified when the mode changes.
        """
    def removeModeChangeApproveListener(self, rxListener: 'XModeChangeApproveListener_7807110c') -> None:
        """
        remove the given listener from the list of components to be notified when the mode is about to change.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
    def removeModeChangeListener(self, rxListener: 'XModeChangeListener_9c30e2f') -> None:
        """
        removes the given listener from the list of components to be notified when the mode changes.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_update_listener import XUpdateListener as XUpdateListener_d4eb0cbd

class XUpdateBroadcaster(XInterface_8f010a43):
    """
    is the broadcaster interface for sending \"approveUpdate\" and \"updated\" events.
    
    The component supporting this interface must do approval calls (XUpdateListener.approveUpdate()) immediately before the data is updated, and notification calls (XUpdateListener.updated()) immediately afterwards.

    See Also:
        `API XUpdateBroadcaster <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XUpdateBroadcaster.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.form.XUpdateBroadcaster']

    def addUpdateListener(self, aListener: 'XUpdateListener_d4eb0cbd') -> None:
        """
        adds the specified listener to receive the events \"approveUpdate\" and \"updated\".
        """
    def removeUpdateListener(self, aListener: 'XUpdateListener_d4eb0cbd') -> None:
        """
        removes the specified listener.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class CharSet(object):
    """
    Const

    These values are used to specify the characters which are available in a font and their codes.
    
    The currently defined constants of CharSet have the same numerical values as the corresponding enum values of the C/C++ rtl_TextEncoding (from rtl/textenc.h). This correspondence is by design. Since CharSet is deprecated, however, it is not planned to add further constants to keep it in sync with rtl_TextEncoding.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API CharSet <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1CharSet.html>`_
    """
    DONTKNOW: Literal[0]
    """
    specifies an unknown character set.
    """
    ANSI: Literal[1]
    """
    specifies the ANSI character set.
    """
    MAC: Literal[2]
    """
    specifies the Apple Macintosh character set.
    """
    IBMPC_437: Literal[3]
    """
    specifies the IBM PC character set number 437.
    """
    IBMPC_850: Literal[4]
    """
    specifies the IBM PC character set number 850.
    """
    IBMPC_860: Literal[5]
    """
    specifies the IBM PC character set number 860.
    """
    IBMPC_861: Literal[6]
    """
    specifies the IBM PC character set number 861.
    """
    IBMPC_863: Literal[7]
    """
    specifies the IBM PC character set number 863.
    """
    IBMPC_865: Literal[8]
    """
    specifies the IBM PC character set number 865.
    """
    SYSTEM: Literal[9]
    """
    specifies the system character set.
    """
    SYMBOL: Literal[10]
    """
    specifies a set of symbols.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
    from .x_slide_preview_cache_listener import XSlidePreviewCacheListener as XSlidePreviewCacheListener_af761239
    from ..geometry.integer_size2_d import IntegerSize2D as IntegerSize2D_f2690d53
    from ..rendering.x_bitmap import XBitmap as XBitmap_b1b70b7b
    from ..rendering.x_canvas import XCanvas as XCanvas_b19b0b7a
    from ..uno.x_interface import XInterface as XInterface_8f010a43

class XSlidePreviewCache(ABC):
    """
    A cache of preview bitmaps for the slides of one Impress or Draw document in one size.
    
    There may be more than one cache for one document. These are internally connected and for missing previews one cache may take it from another cache and scale it to the desired size. When a preview is not present then it is created asynchronously. On creation all registered listeners are notified.
    
    Slides are referenced via their index in an XIndexAccess container in order to allow multiple references to a single slide (custom presentations).

    See Also:
        `API XSlidePreviewCache <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCache.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.XSlidePreviewCache']

    def addPreviewCreationNotifyListener(self, xListener: 'XSlidePreviewCacheListener_af761239') -> None:
        """
        Register a listener that is called when a preview has been created asynchronously.
        """
    def getSlidePreview(self, nSlideIndex: int, xCanvas: 'XCanvas_b19b0b7a') -> 'XBitmap_b1b70b7b':
        """
        Return a preview for the given slide index.
        
        The returned bitmap may be the requested preview, a preview of the preview, i.e. a scaled up or down version, or an empty reference when the preview is not yet present.
        
        This call may lead to the asynchronous creation of the requested preview. In that case all registered listeners are notified when the preview has been created.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def pause(self) -> None:
        """
        Stop the asynchronous creation of previews temporarily.
        
        Call resume() to restart it.
        """
    def removePreviewCreationNotifyListener(self, xListener: 'XSlidePreviewCacheListener_af761239') -> None:
        """
        Remove a previously registered listener for preview creations.
        """
    def resume(self) -> None:
        """
        Resume the asynchronous creation of slide previews.
        """
    def setDocumentSlides(self, xSlides: 'XIndexAccess_f0910d6d', xDocument: 'XInterface_8f010a43') -> None:
        """
        Set the set of slides for which the cache will provide the previews.
        
        All slides in the given XIndexAccess are required to come from the given model.
        """
    def setPreviewSize(self, aSize: 'IntegerSize2D_f2690d53') -> None:
        """
        Define the size of the previews that are managed by the called cache.
        """
    def setVisibleRange(self, nFirstVisibleSlideIndex: int, nLastVisibleSlideIndex: int) -> None:
        """
        Define which slides are currently visible on the screen and which are not.
        
        This information is used for give preview creation for visible slides a higher priority than for those slides that are not visible.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb.application
from typing_extensions import Literal
"""
Const

specifies the different basic operations a CopyTableWizard can do.

**since**

    OOo 2.4

See Also:
    `API CopyTableOperation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1CopyTableOperation.html>`_
"""
CopyDefinitionAndData: Literal[0]
"""
specifies that the wizard should copy the source table to the target database, by creating a new table and copying all data.
"""
CopyDefinitionOnly: Literal[1]
"""
specifies that the wizard should copy the source table to the target database, by only creating a new table with the same structure as the source table.
"""
CreateAsView: Literal[2]
"""
specifies the wizard should create the source table as view

This option is not available if the target database does not support views.
"""
AppendData: Literal[3]
"""
specifies the wizard should append the source table's data to an existing table in the target database.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from .result_column import ResultColumn as ResultColumn_a4980b2e
from .x_column import XColumn as XColumn_70650907
from .x_column_update import XColumnUpdate as XColumnUpdate_aebd0b6a

class DataColumn(ResultColumn_a4980b2e, XColumn_70650907, XColumnUpdate_aebd0b6a):
    """
    Service Class

    defines a column used for a result set which contains the data definition and the data of the column of the current row of a result set.

    See Also:
        `API DataColumn <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DataColumn.html>`_
    """
    @property
    def OriginalValue(self) -> object:
        """
        contains the original value of the column.
        """
    @property
    def Value(self) -> object:
        """
        contains the column's value.
        
        This could be a constraint property, to veto modifications, if a new value does not fit into rules defined for the column.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing
from typing_extensions import Literal
import typing
from .x_shape import XShape as XShape_8fd00a3d
if typing.TYPE_CHECKING:
    from ..awt.x_control_model import XControlModel as XControlModel_affc0b7e

class XControlShape(XShape_8fd00a3d):
    """
    is implemented by a ControlShape to access the controls model.

    See Also:
        `API XControlShape <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XControlShape.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.XControlShape']

    def getControl(self) -> 'XControlModel_affc0b7e':
        """
        returns the control model of this Shape.
        """
    def setControl(self, xControl: 'XControlModel_affc0b7e') -> None:
        """
        sets the control model for this Shape.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from .x_label_range import XLabelRange as XLabelRange_af090b46

class LabelRange(XLabelRange_af090b46):
    """
    Service Class

    represents a cell area that contains labels and values related to the labels.
    
    Label ranges can be used in formulas to refer to cells in cell ranges with row or column titles. The formula uses the cell value that is related to the specified row or column title.

    See Also:
        `API LabelRange <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1LabelRange.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.presentation
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
from ..container.x_named import XNamed as XNamed_a6520b08

class CustomPresentation(XIndexContainer_1c040ebe, XNamed_a6520b08):
    """
    Service Class

    A custom presentation can show the pages of its presentation in a customized order.
    
    Such a presentation can use certain pages more than once, but it does not necessarily use all of the pages.

    See Also:
        `API CustomPresentation <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1presentation_1_1CustomPresentation.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .date_time import DateTime as DateTime_84de09d3


class RevisionTag(object):
    """
    Struct Class

    represents the information that describes a revision of something.

    See Also:
        `API RevisionTag <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1RevisionTag.html>`_
    """
    typeName: Literal['com.sun.star.util.RevisionTag']

    def __init__(self, TimeStamp: typing.Optional[DateTime_84de09d3] = ..., Author: typing.Optional[str] = ..., Comment: typing.Optional[str] = ..., Identifier: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            TimeStamp (DateTime, optional): TimeStamp value.
            Author (str, optional): Author value.
            Comment (str, optional): Comment value.
            Identifier (str, optional): Identifier value.
        """


    @property
    def TimeStamp(self) -> DateTime_84de09d3:
        """
        contains the time when the revision was created ( can be invalid )
        """


    @property
    def Author(self) -> str:
        """
        contains an identifier for the author that created the revision( can be empty )
        """


    @property
    def Comment(self) -> str:
        """
        contains a comment that the author has left for this revision ( can be empty )
        """


    @property
    def Identifier(self) -> str:
        """
        contains a unique identifier for the revision and must not be empty
        
        This identifier can have any form. It can be something like \"1.2.3\" or \"Version 1\" etc. It depends on the revision control system how it names the revisions.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.frame
from typing_extensions import Literal
"""
Const

provides information about a supported command

**since**

    OOo 2.0

See Also:
    `API CommandGroup <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1frame_1_1CommandGroup.html>`_
"""
INTERNAL: Literal[0]
"""
specifies internal commands.
"""
APPLICATION: Literal[1]
"""
specifies application based commands.
"""
VIEW: Literal[2]
"""
specifies view specific commands.
"""
DOCUMENT: Literal[3]
"""
specifies document specific commands.
"""
EDIT: Literal[4]
"""
specifies edit specific commands.
"""
MACRO: Literal[5]
"""
specifies commands used by the built-in Basic.
"""
OPTIONS: Literal[6]
"""
specifies commands to change options.
"""
MATH: Literal[7]
"""
specifies math specific commands.
"""
NAVIGATOR: Literal[8]
"""
specifies navigate commands.
"""
INSERT: Literal[9]
"""
specifies insert commands.
"""
FORMAT: Literal[10]
"""
specifies commands that are related to formats.
"""
TEMPLATE: Literal[11]
"""
specifies commands that are related to templates.
"""
TEXT: Literal[12]
"""
specifies text specific commands.
"""
FRAME: Literal[13]
"""
specifies frame specific commands.
"""
GRAPHIC: Literal[14]
"""
specifies commands that are related to graphical data.
"""
TABLE: Literal[15]
"""
specifies commands that are related to tables.
"""
ENUMERATION: Literal[16]
"""
specifies commands that are related to bullets and numbering.
"""
DATA: Literal[17]
"""
specifies commands that are related to data.
"""
SPECIAL: Literal[18]
"""
specifies special commands.
"""
IMAGE: Literal[19]
"""
specifies commands that are related to images.
"""
CHART: Literal[20]
"""
specifies chart specific commands.
"""
EXPLORER: Literal[21]
"""
specifies explorer specific commands.
"""
CONNECTOR: Literal[22]
"""
specifies commands that are related to connectors.
"""
MODIFY: Literal[23]
"""
specifies commands that are related to modifications.
"""
DRAWING: Literal[24]
"""
specifies commands that are related to drawing.
"""
CONTROLS: Literal[25]
"""
specifies commands that are related to controls.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_text_view_cursor_supplier import XTextViewCursorSupplier as XTextViewCursorSupplier_4c931037
from ..view.office_document_view import OfficeDocumentView as OfficeDocumentView_fd320de9

class TextDocumentView(OfficeDocumentView_fd320de9, XPropertySet_bc180bfa, XTextViewCursorSupplier_4c931037):
    """
    Service Class

    specifies the view of a TextDocument.
    
    **since**
    
        OOo 2.0

    See Also:
        `API TextDocumentView <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextDocumentView.html>`_
    """
    @property
    def IsConstantSpellcheck(self) -> bool:
        """
        specifies if spell checking should be done while typing.
        
        **since**
        
            OOo 2.0
        """
    @property
    def IsHideSpellMarks(self) -> bool:
        """
        specifies if the marks for misspelled text should be displayed.
        
        **since**
        
            OOo 2.0
        """
    @property
    def LineCount(self) -> int:
        """
        returns the number of lines in the document
        
        Since the document needs to be formatted to get the result obtaining this value may take some time.
        
        Empty paragraphs are not counted.
        
        **since**
        
            OOo 2.0
        """
    @property
    def PageCount(self) -> int:
        """
        returns the number of pages in the document
        
        Since the document needs to be formatted to get the result obtaining this value may take some time.
        
        **since**
        
            OOo 2.0
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.resource
from typing_extensions import Literal
import typing
from .x_string_resource_persistence import XStringResourcePersistence as XStringResourcePersistence_cabc130c
if typing.TYPE_CHECKING:
    from ..embed.x_storage import XStorage as XStorage_8e460a32

class XStringResourceWithStorage(XStringResourcePersistence_cabc130c):
    """
    Extends XStringResourcePersistence by methods to handle an associated com.sun.star.embed.XStorage instance.

    See Also:
        `API XStringResourceWithStorage <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1resource_1_1XStringResourceWithStorage.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.resource.XStringResourceWithStorage']

    def setStorage(self, Storage: 'XStorage_8e460a32') -> None:
        """
        Associates a storage to the StringResourceWithStorage instance which is used on subsequent calls of store().
        
        This call has to be used carefully as it removes the storage previously connected to the StringResourceWithStorage. It may force the implementation to reload data from the previous storage before releasing it. The StringResourceManager will be modified after calling this method as the data isn't stored to the new storage yet. storeAsStorage() should be preferred as it directly stores the data to the new storage and afterwards this storage is in sync with the resource data.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def storeAsStorage(self, Storage: 'XStorage_8e460a32') -> None:
        """
        Stores all string table data to a storage and associates this storage to this instance as if setStorage() was called with this storage.
        
        The modified state will be unmodified after the call.
        
        This method can throw all exceptions thrown by the methods of com.sun.star.embed.XStorage

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
import typing
from ..document.x_embedded_object_supplier import XEmbeddedObjectSupplier as XEmbeddedObjectSupplier_8b631174
from .base_frame import BaseFrame as BaseFrame_8f020a33
if typing.TYPE_CHECKING:
    from ..frame.x_model import XModel as XModel_7a6e095c
    from ..lang.x_component import XComponent as XComponent_98dc0ab5

class TextEmbeddedObject(BaseFrame_8f020a33, XEmbeddedObjectSupplier_8b631174):
    """
    Service Class

    provides access to the properties and methods of an embedded object.

    See Also:
        `API TextEmbeddedObject <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextEmbeddedObject.html>`_
    """
    @property
    def CLSID(self) -> str:
        """
        """
    @property
    def Component(self) -> 'XComponent_98dc0ab5':
        """
        This is the component for the OLE2 object.
        """
    @property
    def Model(self) -> 'XModel_7a6e095c':
        """
        This is the model for the OLE2 object.
        
        This property if void if the OLE2 is not an Office component.
        """


